@@ -11,29 +11,39 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Test::Pod::No404s;
-BEGIN {
-  $Dist::Zilla::Plugin::Test::Pod::No404s::VERSION = '1.001';
-}
-BEGIN {
-  $Dist::Zilla::Plugin::Test::Pod::No404s::AUTHORITY = 'cpan:RWSTAUNER';
-}
-# ABSTRACT: Add release tests for POD HTTP links
+# git description: v1.001-6-g1cdb3df
 
+our $AUTHORITY = 'cpan:RWSTAUNER';
+# ABSTRACT: Add release tests for POD HTTP links
+$Dist::Zilla::Plugin::Test::Pod::No404s::VERSION = '1.002';
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
+with 'Dist::Zilla::Role::PrereqSource';
+
+sub register_prereqs {
+  my $self = shift;
+
+  $self->zilla->register_prereqs(
+    {
+        type  => 'requires',
+        phase => 'develop',
+    },
+    'Test::Pod::No404s' => '0',
+  );
+}
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
 1;
 
-
-
-
 =pod
 
-=for :stopwords Randy Stauner cpan testmatrix url annocpan anno bugtracker rt cpants
-kwalitee diff irc mailto metadata placeholders
+=encoding UTF-8
+
+=for :stopwords Randy Stauner ACKNOWLEDGEMENTS Dave Rolsky cpan testmatrix url annocpan
+anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders
+metacpan
 
 =head1 NAME
 
@@ -41,7 +51,7 @@ Dist::Zilla::Plugin::Test::Pod::No404s - Add release tests for POD HTTP links
 
 =head1 VERSION
 
-version 1.001
+version 1.002
 
 =head1 SYNOPSIS
 
@@ -68,6 +78,8 @@ before actually attempting C<dzil release>.
 So using C<dzil smoke> instead of C<dzil test>
 will skip the 404 network tests.
 
+=for Pod::Coverage register_prereqs
+
 =head1 SEE ALSO
 
 =over 4
@@ -95,71 +107,37 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-Search CPAN
+MetaCPAN
 
-The default CPAN search engine, useful to view POD in HTML format.
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://search.cpan.org/dist/Dist-Zilla-Plugin-Test-Pod-No404s>
-
-=item *
-
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Dist-Zilla-Plugin-Test-Pod-No404s>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Dist-Zilla-Plugin-Test-Pod-No404s>
-
-=item *
-
-CPAN Testers
-
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
-
-L<http://www.cpantesters.org/distro/D/Dist-Zilla-Plugin-Test-Pod-No404s>
-
-=item *
-
-CPAN Testers Matrix
-
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
-
-L<http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-Test-Pod-No404s>
-
-=item *
-
-CPAN Testers Dependencies
-
-The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
-
-L<http://deps.cpantesters.org/?module=Dist::Zilla::Plugin::Test::Pod::No404s>
+L<http://metacpan.org/release/Dist-Zilla-Plugin-Test-Pod-No404s>
 
 =back
 
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-dist-zilla-plugin-test-pod-no404s at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Dist-Zilla-Plugin-Test-Pod-No404s>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Dist-Zilla-Plugin-Test-Pod-No404s>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
 
 
-L<http://github.com/rwstauner/Dist-Zilla-Plugin-Test-Pod-No404s>
+L<https://github.com/rwstauner/Dist-Zilla-Plugin-Test-Pod-No404s>
 
-  git clone http://github.com/rwstauner/Dist-Zilla-Plugin-Test-Pod-No404s
+  git clone https://github.com/rwstauner/Dist-Zilla-Plugin-Test-Pod-No404s.git
 
 =head1 AUTHOR
 
 Randy Stauner <rwstauner@cpan.org>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Dave Rolsky
+
+Dave Rolsky <autarch@urth.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 by Randy Stauner.
@@ -169,7 +147,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 ___[ xt/release/pod-no404s.t ]___
 #!perl
